@@ -4,4 +4,4 @@
  * Please see the file COPYING in this directory for license information.
  */
 
-extern int hash_crc32(char *buf, int i0, int nbuf);
+extern uint32_t hash_crc32(unsigned char *buf, int i0, int nbuf);
