@@ -5,6 +5,6 @@
  */
 
 extern void hash_reset(int);
-extern int hash_contains(unsigned);
-extern void hash_insert(unsigned);
-extern int hash_delete(unsigned);
+extern int hash_contains(uint32_t);
+extern void hash_insert(uint32_t);
+extern int hash_delete(uint32_t);
